==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/PURCHASEORDERINFO.java <==

package net.datastream.schemas.mp_fields;

import java.math.BigInteger;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="PURCHASEORDER" type="{http://schemas.datastream.net/MP_fields}CODE30_Type"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID" minOccurs="0"/>
 *         &lt;element name="PURCHASEORDERLINE" type="{http://www.w3.org/2001/XMLSchema}positiveInteger"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "purchaseorder",
    "organizationid",
    "purchaseorderline"
})
@XmlRootElement(name = "PURCHASEORDERINFO")
public class PURCHASEORDERINFO {

    @XmlElement(name = "PURCHASEORDER", required = true)
    protected String purchaseorder;
    @XmlElement(name = "ORGANIZATIONID")
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "PURCHASEORDERLINE", required = true)
    @XmlSchemaType(name = "positiveInteger")
    protected BigInteger purchaseorderline;

    /**
     * Obtient la valeur de la propriété purchaseorder.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPURCHASEORDER() {
        return purchaseorder;
    }

    /**
     * Définit la valeur de la propriété purchaseorder.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPURCHASEORDER(String value) {
        this.purchaseorder = value;
    }

    /**
     * Obtient la valeur de la propriété organizationid.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Définit la valeur de la propriété organizationid.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Obtient la valeur de la propriété purchaseorderline.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getPURCHASEORDERLINE() {
        return purchaseorderline;
    }

    /**
     * Définit la valeur de la propriété purchaseorderline.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setPURCHASEORDERLINE(BigInteger value) {
        this.purchaseorderline = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/PURCHASEORDERINFO.java <==

package net.datastream.schemas.mp_fields;

import java.math.BigInteger;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="PURCHASEORDER" type="{http://schemas.datastream.net/MP_fields}CODE30_Type"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID" minOccurs="0"/>
 *         &lt;element name="PURCHASEORDERLINE" type="{http://www.w3.org/2001/XMLSchema}positiveInteger"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "purchaseorder",
    "organizationid",
    "purchaseorderline"
})
@XmlRootElement(name = "PURCHASEORDERINFO")
public class PURCHASEORDERINFO {

    @XmlElement(name = "PURCHASEORDER", required = true)
    protected String purchaseorder;
    @XmlElement(name = "ORGANIZATIONID")
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "PURCHASEORDERLINE", required = true)
    @XmlSchemaType(name = "positiveInteger")
    protected BigInteger purchaseorderline;

    /**
     * Gets the value of the purchaseorder property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPURCHASEORDER() {
        return purchaseorder;
    }

    /**
     * Sets the value of the purchaseorder property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPURCHASEORDER(String value) {
        this.purchaseorder = value;
    }

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Gets the value of the purchaseorderline property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getPURCHASEORDERLINE() {
        return purchaseorderline;
    }

    /**
     * Sets the value of the purchaseorderline property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setPURCHASEORDERLINE(BigInteger value) {
        this.purchaseorderline = value;
    }

}
